%global with_python3 0%{?fedora}

Name:           python-docker-squash
Version:        1.0.5
Release:        1%{?dist}
Summary:        Docker layer squashing tool
Group:          Development/Tools
License:        MIT
URL:            https://github.com/goldmann/docker-squash
Source0:        https://github.com/goldmann/docker-squash/archive/%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  python-six
BuildRequires:  pytest
BuildRequires:  python-mock
BuildRequires:  python-docker-py

%global _description \
Tool to squash layers in Docker images.

%description %_description

%package -n python2-docker-squash
Summary:        %{summary}

Requires:       python-setuptools
Requires:       python-six
Requires:       python-docker-py

Provides:       python-docker-scripts = %{version}-%{release}
Obsoletes:      python-docker-scripts <= 1.0.0-0.2.rc2
%{?python_provide:%python_provide python2-docker-squash}

%description -n python2-docker-squash %_description

%if 0%{?with_python3}
%package -n python3-docker-squash
Summary:        %{summary}

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-six
BuildRequires:  python3-pytest
BuildRequires:  python3-mock
BuildRequires:  python3-docker-py
Requires:       python3-setuptools
Requires:       python3-six
Requires:       python3-docker-py

Provides:       python3-docker-scripts = %{version}-%{release}
Obsoletes:      python3-docker-scripts <= 1.0.0-0.2.rc2
%{?python_provide:%python_provide python3-docker-squash}

%description -n python3-docker-squash %_description
%endif

%prep
%setup -qn docker-squash-%{version}

%if 0%{?with_python3}
rm -rf %{py3dir}
cp -a . %{py3dir}
find %{py3dir} -name '*.py' | xargs sed -i '1s|^#!python|#!%{__python3}|'
%endif

find -name '*.py' | xargs sed -i '1s|^#!python|#!%{__python2}|'

%build
%{__python} setup.py build

%if 0%{?with_python3}
pushd %{py3dir}
%{__python3} setup.py build
popd
%endif

%check
py.test -v tests/test_unit*.py

%install
%if 0%{?with_python3}
pushd %{py3dir}
%{__python3} setup.py install --skip-build --root %{buildroot}
mv %{buildroot}%{_bindir}/docker-squash %{buildroot}%{_bindir}/docker-squash3
popd
%endif

%{__python} setup.py install --skip-build --root %{buildroot}

%files
%doc README.rst
%license LICENSE
%{_bindir}/docker-squash
%dir %{python2_sitelib}/docker_squash
%{python2_sitelib}/docker_squash/*
%{python2_sitelib}/docker_squash-%{version}-py2.*.egg-info

%if 0%{?with_python3}
%files -n python3-docker-squash
%doc README.rst
%license LICENSE
%{_bindir}/docker-squash3
%dir %{python3_sitelib}/docker_squash
%{python3_sitelib}/docker_squash/*
%{python3_sitelib}/docker_squash-%{version}-py3.*.egg-info
%endif

%changelog
* Wed Dec 07 2016 Marek Goldmann <mgoldman@redhat.com> - 1.0.5-1
- Upstream release 1.0.5

* Thu Sep 01 2016 Marek Goldmann <mgoldman@redhat.com> - 1.0.4-1
- Upstream release 1.0.4

* Thu Sep 01 2016 Marek Goldmann <mgoldman@redhat.com> - 1.0.3-2
- Apply patch for gh#122

* Tue Aug 30 2016 Marek Goldmann <mgoldman@redhat.com> - 1.0.3-1
- Upstream release 1.0.3

* Thu Aug 25 2016 Marek Goldmann <mgoldman@redhat.com> - 1.0.2-1
- Upstream release 1.0.2

* Mon Aug 22 2016 Marek Goldmann <mgoldman@redhat.com> - 1.0.1-1
- Upstream release 1.0.1

* Mon Aug 01 2016 Marek Goldmann <mgoldman@redhat.com> - 1.0.1-0.1.rc1
- Upstream release 1.0.1rc1

* Mon May 30 2016 Marek Goldmann <mgoldman@redhat.com> - 1.0.0-0.10.rc6
- Do not use non-existing macros

* Mon May 30 2016 Marek Goldmann <mgoldman@redhat.com> - 1.0.0-0.9.rc6
- Rebuild

* Fri May 27 2016 Marek Goldmann <mgoldman@redhat.com> - 1.0.0-0.8.rc6
- Upstream 1.0.0rc6 release

* Mon May 23 2016 Marek Goldmann <mgoldman@redhat.com> - 1.0.0-0.7.rc5
- 1.0.0rc5 release

* Tue May 10 2016 Marek Goldmann <mgoldman@redhat.com> - 1.0.0-0.6.rc4
- Release bump

* Wed Apr 13 2016 Marek Goldmann <mgoldman@redhat.com> - 1.0.0-0.5.rc4
- Adapt to current guidelines thanks to Zbigniew Jędrzejewski-Szmek

* Fri Apr 08 2016 Marek Goldmann <mgoldman@redhat.com> - 1.0.0-0.4.rc4
- Upstream release 1.0.0rc4

* Fri Apr 01 2016 Marek Goldmann <mgoldman@redhat.com> - 1.0.0-0.3.rc3
- Project rename and new 1.0.0rc3 release

* Fri Apr 01 2016 Marek Goldmann <mgoldman@redhat.com> - 1.0.0-0.2.rc2
- Someone forgot to upload sources...

* Fri Apr 01 2016 Marek Goldmann - 1.0.0-0.1.rc2
- Upstream release 1.0.0rc2

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.4.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Jan 18 2016 Martin Milata <mmilata@redhat.com> - 0.4.4-1
- Upstream release 0.4.4

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.2-3
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Jun 11 2015 Marek Goldmann <mgoldman@redhat.com> - 0.4.2-1
- Upstream release 0.4.2

* Tue Jun 02 2015 Marek Goldmann <mgoldman@redhat.com> - 0.4.1-1
- Upstream release 0.4.1

* Wed May 27 2015 Marek Goldmann <mgoldman@redhat.com> - 0.4.0-1
- Upstream release 0.4.0
- Run unit tests at build time

* Mon May 18 2015 Marek Goldmann <mgoldman@redhat.com> - 0.3.8-1
- Upstream release 0.3.8

* Fri May 15 2015 Marek Goldmann <mgoldman@redhat.com> - 0.3.7-1
- Upstream release 0.3.7
- Make sure the /usr/lib/python2.7/site-packages/docker_scripts
  is owned by this package

* Thu May 14 2015 Marek Goldmann <mgoldman@redhat.com> - 0.3.6-1
- Upstream release 0.3.6

* Tue May 12 2015 Marek Goldmann <mgoldman@redhat.com> - 0.3.4-1
- Initial packaging

